@@ -8,4 +8,12 @@ from physicsLab.unionElements import *
 # 天体物理实验
 from physicsLab.astrophysics import *
 # 电与磁实验
-from physicsLab.electromagnetism import *
\ No newline at end of file
+from physicsLab.electromagnetism import *
+# 自定义异常类
+from physicsLab.errors import *
+
+'''
+__all__ = [
+    
+]
+'''
\ No newline at end of file
